==> nextcloud-app-mail-0.10.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/cs.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Pošta",
    "Loading accounts" : "Načítání účtů",
    "Error while loading the accounts." : "Chyba při načítání účtů.",
    "Can not load this folder." : "Tuto složku nelze načíst.",
    "Searching for {query}" : "Hledání pro {query}",
    "Error while deleting message." : "Chyba při mazání zprávy.",
    "Forwarded message" : "Přeposlaná zpráva",
    "Choose a folder to store the attachment in" : "Vyber adresář pro uložení přílohy",
    "Attachments saved to Files." : "Přílohy uloženy do Souborů.",
    "Attachment saved to Files." : "Příloha uložena do Souborů.",
    "Error while saving attachments to Files." : "Chyba při ukládání příloh do Souborů.",
    "Error while saving attachment to Files." : "Chyba při ukládání přílohy do Souborů.",
    "Message flag could not be set." : "Značka zpráva nemohla být nastavena.",
    "Could not move message." : "Nelze přesunout zprávu.",
    "Invalid account" : "Neplatný účet",
    "Invalid folder" : "Neplatná složka",
    "Error while creating the account: " : "Chyba při vytváření účtu:",
    "Unknown error" : "Neznámá chyba",
    "Error while updating the account: " : "Chyba při aktualizaci účtu",
    "All inboxes" : "Všechny schránky",
    "you" : "vy",
    "Send message to {email}" : "Poslat e-mail na {email}",
    "Could not load {tag}{name}{endtag}" : "Nelze načíst {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Došlo k problému s načtením {tag}{name}{endtag}",
    "Could not load your message" : "Nezdařilo se načtení vaší zprávy",
    "Could not load the desired message" : "Nelze načíst vyžádanou zprávu",
    "Could not load the message" : "Nelze načíst zprívu",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nová zpráva\nod {from}","%n nové zprávy\nod {from}","%n nových zpráv\nod {from}","%n nových zpráv\nod {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Save" : "Uložit",
    "Saved" : "Uloženo",
    "Show all folders" : "Zobrazit všechny složky",
    "Collapse folders" : "Sbalit složky",
    "Error while deleting account." : "Chyba při mazání účtu.",
    "Choose a file to add as attachment" : "Vyberte soubor k přiložení",
    "An error occurred while uploading {fname}" : "Došlo k chybě při nahrávání souboru {fname}",
    "Reply" : "Odpověď",
    "Send" : "Odeslat",
    "Sending …" : "Odesílání…",
    "Message sent!" : "Zpráva odeslána!",
    "Server error" : "Chyba serveru",
    "An unknown error occurred" : "Nastala neznámá chyba",
    "Opening HTML drafts is not supported yet." : "Otevírání HTML konceptů ještě není podporováno.",
    "No writable calendars found" : "Nebyly nalezeny žádné zapisovatelné kalendáře",
    "Error while importing the calendar event" : "Chyba při importu události kalendáře",
    "Error while downloading calendar event" : "Chyba při stahování události kalendáře",
    "& others" : "a další",
    "Error while loading messages." : "Chyba během načítání zpráv.",
    "Error while refreshing messages." : "Chyba během načítání zpráv.",
    "Setting up your account" : "Nastavení účtu",
    "Inbox" : "Doručená",
    "Sent" : "Odeslaná",
    "Drafts" : "Koncepty",
    "Archive" : "Archiv",
    "Trash" : "Koš",
    "Junk" : "Spam",
    "All" : "Vše",
    "Favorites" : "Oblíbené",
    "Auto detect failed. Please use manual mode." : "Autodetekce selhala. Použijte prosím ruční nastavení.",
    "Updating account failed: " : "Aktualizace účtu selhala:",
    "Creating account failed: " : "Vytvoření účtu selhalo:",
    "Delete permanently" : "Trvale odstranit",
    "IMAP web client" : "Webový IMAP klient",
    "Error loading message" : "Chyba načtení zprávy",
    "Settings" : "Nastavení",
    "Forwarding to %s" : "Přeposílá na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikněte zde, pokud nebudete automaticky přesměrováni během příštích několika vteřin.",
    "Redirect" : "Přesměrovat",
    "The link leads to %s" : "Odkaz vede na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Pokud nechcete tuto stránku navštívit, můžete se vrátit do <a href=\"%s\">e-mailu</a>.",
    "Continue to %s" : "Pokračovat na %s",
    "Delete account" : "Smazat účet",
    "Try again" : "Zkusit znovu",
    "New message" : "Nová zpráva",
    "Account Settings" : "Nastavení účtu",
    "Aliases" : "Aliasy",
    "Mail address" : "E-mailová adresa",
    "Display Name" : "Zobrazované jméno",
    "Account" : "Účet",
    "Delete" : "Smazat",
    "Keyboard shortcuts" : "Klávesové zkratky",
    "Speed up your Mail experience with these quick shortcuts." : "Urychlete svůj Mail pomocí těchto rychlých zkratek.",
    "Compose new message" : "Nová zpráva",
    "Newer message" : "Novější zpráva",
    "Older message" : "Starší zpráva",
    "Toggle star" : "Přepnout hvězdu",
    "Toggle unread" : "Přepnout nepřečtené",
    "Search" : "Hledat",
    "Refresh" : "Obnovit",
    "Connect your mail account" : "Připojit e-mailový účet",
    "Name" : "Jméno",
    "Mail Address" : "E-mailová adresa",
    "Password" : "Heslo",
    "Manual configuration" : "Manuální nastavení",
    "IMAP Host" : "IMAP hostitel",
    "IMAP security" : "IMAP zabezpečení",
    "None" : "Žádné",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP uživatel",
    "IMAP Password" : "IMAP heslo",
    "SMTP Host" : "SMTP hostitel",
    "SMTP security" : "SMTP zabezpečení",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP uživatel",
    "SMTP Password" : "SMTP heslo",
    "Connect" : "Připojit",
    "from" : "od",
    "to" : "komu",
    "cc" : "kopie",
    "bcc" : "skrytá kopie",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Poznámka: Email pochází z noreply adresy pravděpodobně nebude možnost přečíst odpověď.",
    "Subject" : "Předmět",
    "Save all to Files" : "Uložit vše do Souborů",
    "Add mail account" : "Přidat e-mailový účet",
    "Use Gravatar and favicon avatars" : "Použijte Gravatar a favicon avatary",
    "No search results for" : "Nic nenalezeno pro",
    "The images have been blocked to protect your privacy." : "Obrázky byly zablokovány pro ochranu vašeho soukromí.",
    "Show images from this sender" : "Zobrazit obrázky od tohoto odesílatele",
    "Forward" : "Přeposlat",
    "No messages in this folder" : "V této složce nejsou žádné zprávy",
    "Upload attachment" : "Nahrát přílohu",
    "Add attachment from Files" : "Přidat přílohu ze Souborů",
    "Import into calendar" : "Importovat do kalendáře",
    "Download attachment" : "Stáhnout přílohu",
    "Save to Files" : "Uložit do Souborů"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-app-mail-0.11.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/cs.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-mail",
    "Loading accounts" : "Načítání účtů",
    "Error while loading the accounts." : "Chyba při načítání účtů.",
    "Can not load this folder." : "Tuto složku se nedaří načíst.",
    "Searching for {query}" : "Hledání pro {query}",
    "Error while deleting message." : "Chyba při mazání zprávy.",
    "Forwarded message" : "Přeposlaná zpráva",
    "Choose a folder to store the attachment in" : "Vyberte složku pro uložení přílohy",
    "Attachments saved to Files." : "Přílohy uloženy do Souborů.",
    "Attachment saved to Files." : "Příloha uložena do Souborů.",
    "Error while saving attachments to Files." : "Chyba při ukládání příloh do Souborů.",
    "Error while saving attachment to Files." : "Chyba při ukládání přílohy do Souborů.",
    "Message flag could not be set." : "Značka zpráva nemohla být nastavena.",
    "Could not move message." : "Nelze přesunout zprávu.",
    "Invalid account" : "Neplatný účet",
    "Invalid folder" : "Neplatná složka",
    "Error while creating the account: " : "Chyba při vytváření účtu:",
    "Unknown error" : "Neznámá chyba",
    "Error while updating the account: " : "Chyba při aktualizaci účtu",
    "All inboxes" : "Všechny schránky",
    "you" : "vy",
    "Send message to {email}" : "Poslat e-mail na {email}",
    "Could not load {tag}{name}{endtag}" : "Nedaří se načíst {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Došlo k problému s načtením {tag}{name}{endtag}",
    "Could not load your message" : "Nezdařilo se načtení vaší zprávy",
    "Could not load the desired message" : "Nelze načíst vyžádanou zprávu",
    "Could not load the message" : "Nelze načíst zprívu",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nová zpráva\nod {from}","%n nové zprávy\nod {from}","%n nových zpráv\nod {from}","%n nových zpráv\nod {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Save" : "Uložit",
    "Saved" : "Uloženo",
    "Show all folders" : "Zobrazit všechny složky",
    "Collapse folders" : "Sbalit složky",
    "Error while deleting account." : "Chyba při mazání účtu.",
    "Choose a file to add as attachment" : "Vyberte soubor k přiložení",
    "An error occurred while uploading {fname}" : "Došlo k chybě při nahrávání souboru {fname}",
    "Reply" : "Odpověď",
    "Send" : "Odeslat",
    "Sending …" : "Odesílání…",
    "Message sent!" : "Zpráva odeslána!",
    "Server error" : "Chyba serveru",
    "An unknown error occurred" : "Nastala neznámá chyba",
    "Opening HTML drafts is not supported yet." : "Otevírání HTML konceptů ještě není podporováno.",
    "No writable calendars found" : "Nebyly nalezeny žádné zapisovatelné kalendáře",
    "Error while importing the calendar event" : "Chyba při importu události kalendáře",
    "Error while downloading calendar event" : "Chyba při stahování události kalendáře",
    "& others" : "a další",
    "Error while loading messages." : "Chyba během načítání zpráv.",
    "Error while refreshing messages." : "Chyba během načítání zpráv.",
    "Setting up your account" : "Nastavení účtu",
    "Inbox" : "Doručená",
    "Sent" : "Odeslaná",
    "Drafts" : "Koncepty",
    "Archive" : "Archiv",
    "Trash" : "Koš",
    "Junk" : "Spam",
    "All" : "Vše",
    "Favorites" : "Oblíbené",
    "Auto detect failed. Please use manual mode." : "Automatické zjištění se nezdařilo. Použijte ruční režim.",
    "Updating account failed: " : "Aktualizace účtu se nezdařila:",
    "Creating account failed: " : "Vytvoření účtu se nezdařilo:",
    "Delete permanently" : "Trvale odstranit",
    "IMAP web client" : "Webový IMAP klient",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Snadno použitelný e-mailový klient který se připojí k vámi používanému serveru prostřednictvím protokolů IMAP a SMTP.",
    "Error loading message" : "Chyba načtení zprávy",
    "Settings" : "Nastavení",
    "Forwarding to %s" : "Přeposílá na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Pokud nebudete v následujících několika sekundách přesměrováni, klikněte sem.",
    "Redirect" : "Přesměrovat",
    "The link leads to %s" : "Odkaz vede na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Pokud nechcete tuto stránku navštívit, můžete se vrátit do <a href=\"%s\">e-mailu</a>.",
    "Continue to %s" : "Pokračovat na %s",
    "Delete account" : "Smazat účet",
    "Try again" : "Zkusit znovu",
    "New message" : "Nová zpráva",
    "Account Settings" : "Nastavení účtu",
    "Aliases" : "Alternativní názvy",
    "Mail address" : "E-mailová adresa",
    "Display Name" : "Zobrazované jméno",
    "Account" : "Účet",
    "Toggle read" : "Přepnout čtení",
    "Delete" : "Smazat",
    "Keyboard shortcuts" : "Klávesové zkratky",
    "Speed up your Mail experience with these quick shortcuts." : "Zrychlete své používání aplikace E-mail pomocí těchto pohotových zkratek.",
    "Compose new message" : "Napsat novou zprávu",
    "Newer message" : "Novější zpráva",
    "Older message" : "Starší zpráva",
    "Toggle star" : "Přepnout hvězdu",
    "Toggle unread" : "Přepnout nepřečtené",
    "Search" : "Hledat",
    "Refresh" : "Načíst znovu",
    "Connect your mail account" : "Připojit e-mailový účet",
    "Name" : "Název",
    "Mail Address" : "E-mailová adresa",
    "Password" : "Heslo",
    "Manual configuration" : "Ruční nastavení",
    "IMAP Host" : "IMAP hostitel",
    "IMAP security" : "IMAP zabezpečení",
    "None" : "Žádné",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP uživatel",
    "IMAP Password" : "IMAP heslo",
    "SMTP Host" : "SMTP hostitel",
    "SMTP security" : "SMTP zabezpečení",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP uživatel",
    "SMTP Password" : "SMTP heslo",
    "Connect" : "Připojit",
    "from" : "od",
    "to" : "komu",
    "cc" : "kopie",
    "bcc" : "skrytá kopie",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Poznámka: E-mail pochází z noreply (neodpovídat) adresy pravděpodobně nebude možnost přečíst odpověď.",
    "Subject" : "Předmět",
    "Save all to Files" : "Uložit vše do Souborů",
    "Add mail account" : "Přidat e-mailový účet",
    "Use Gravatar and favicon avatars" : "Použijte Gravatar a favicon avatary",
    "No search results for" : "Nic nenalezeno pro",
    "The images have been blocked to protect your privacy." : "Obrázky byly zablokovány pro ochranu vašeho soukromí.",
    "Show images from this sender" : "Zobrazit obrázky od tohoto odesílatele",
    "Forward" : "Přeposlat",
    "No messages in this folder" : "V této složce nejsou žádné zprávy",
    "Upload attachment" : "Nahrát přílohu",
    "Add attachment from Files" : "Přidat přílohu ze Souborů",
    "Import into calendar" : "Importovat do kalendáře",
    "Download attachment" : "Stáhnout přílohu",
    "Save to Files" : "Uložit do Souborů"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
